grpcservers

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 4, 2024 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ClusterService

type ClusterService struct {
	mrdspb.UnimplementedClustersServer
	// contains filtered or unexported fields
}

func NewClusterService

func NewClusterService(ledger cluster.Ledger) *ClusterService

func (*ClusterService) Create

Create creates a new Cluster

func (*ClusterService) Delete

Delete deletes a Cluster

func (*ClusterService) GetByID

GetByMetadata retrieves a Cluster by its metadata

func (*ClusterService) GetByName

GetByName retrieves a Cluster by its name

func (*ClusterService) List

List returns a list of Clusters that match the provided filters

func (*ClusterService) UpdateStatus

UpdateState updates the state and message of an existing Cluster

type ComputeCapabilityService

type ComputeCapabilityService struct {
	mrdspb.UnimplementedComputeCapabilitiesServer
	// contains filtered or unexported fields
}

func NewComputeCapabilityService

func NewComputeCapabilityService(ledger computecapability.Ledger) *ComputeCapabilityService

func (*ComputeCapabilityService) Create

Create creates a new ComputeCapability

func (*ComputeCapabilityService) Delete

Delete deletes a ComputeCapability

func (*ComputeCapabilityService) GetByID

GetByName retrieves a ComputeCapability by its name

func (*ComputeCapabilityService) GetByName

GetByName retrieves a ComputeCapability by its name

func (*ComputeCapabilityService) List

List returns a list of ComputeCapabilitys that match the provided filters

func (*ComputeCapabilityService) UpdateStatus

UpdateState updates the state and message of an existing ComputeCapability

type DeploymentPlanService

type DeploymentPlanService struct {
	mrdspb.UnimplementedDeploymentPlansServer
	// contains filtered or unexported fields
}

func NewDeploymentPlanService

func NewDeploymentPlanService(ledger deploymentplan.Ledger) *DeploymentPlanService

func (*DeploymentPlanService) AddDeployment

AddDeployment adds a Deployment to an existing DeploymentPlan

func (*DeploymentPlanService) Create

Create creates a new DeploymentPlan

func (*DeploymentPlanService) Delete

Delete deletes a DeploymentPlan by metadata

func (*DeploymentPlanService) GetByID

GetByID retrieves a DeploymentPlan by its ID

func (*DeploymentPlanService) GetByName

GetByName retrieves a DeploymentPlan by its name

func (*DeploymentPlanService) List

List returns a list of DeploymentPlans that match the provided filters

func (*DeploymentPlanService) UpdateDeploymentStatus

UpdateDeploymentStatus updates the status of an existing Deployment

func (*DeploymentPlanService) UpdateStatus

UpdateStatus updates the state of an existing DeploymentPlan

type MetaInstanceService

type MetaInstanceService struct {
	mrdspb.UnimplementedMetaInstancesServer
	// contains filtered or unexported fields
}

func NewMetaInstanceService

func NewMetaInstanceService(ledger metainstance.Ledger) *MetaInstanceService

func (*MetaInstanceService) AddOperation

AddOperation adds an operation to a MetaInstance

func (*MetaInstanceService) AddRuntimeInstance

AddRuntimeInstance adds a runtime instance to a MetaInstance

func (*MetaInstanceService) Create

Create creates a new MetaInstance

func (*MetaInstanceService) Delete

Delete deletes a MetaInstance

func (*MetaInstanceService) GetByID

GetByID retrieves a MetaInstance by its ID

func (*MetaInstanceService) GetByName

GetByName retrieves a MetaInstance by its name

func (*MetaInstanceService) List

List returns a list of MetaInstances that match the provided filters

func (*MetaInstanceService) RemoveOperation

RemoveOperation removes an operation from a MetaInstance

func (*MetaInstanceService) RemoveRuntimeInstance

RemoveRuntimeInstance removes a runtime instance from a MetaInstance

func (*MetaInstanceService) UpdateDeploymentID

UpdateDeploymentID updates the DeploymentID of an existing MetaInstance

func (*MetaInstanceService) UpdateOperationStatus

UpdateOperationStatus updates the status of an operation on a MetaInstance

func (*MetaInstanceService) UpdateRuntimeActiveState

func (*MetaInstanceService) UpdateRuntimeStatus

UpdateRuntimeStatus updates the status of a runtime instance on a MetaInstance

func (*MetaInstanceService) UpdateStatus

UpdateStatus updates the state and message of an existing MetaInstance

type NodeService

type NodeService struct {
	mrdspb.UnimplementedNodesServer
	// contains filtered or unexported fields
}

func NewNodeService

func NewNodeService(ledger node.Ledger) *NodeService

func (*NodeService) AddCapability

func (*NodeService) AddDisruption

AddDisruption adds a disruption to a Node

func (*NodeService) Create

Create creates a new Node

func (*NodeService) Delete

Delete deletes a Node

func (*NodeService) GetByID

GetByID retrieves a Node by its ID

func (*NodeService) GetByName

GetByName retrieves a Node by its name

func (*NodeService) List

List returns a list of Nodes that match the provided filters

func (*NodeService) RemoveCapability

func (*NodeService) RemoveDisruption

func (*NodeService) UpdateDisruptionStatus

UpdateDisruptionStatus updates the status of a disruption on a Node

func (*NodeService) UpdateStatus

UpdateState updates the state and message of an existing Node

Jump to